{% extends "endpoint/main.html" %}
{% block graph_content %}
    <p>Select a number of items below to reduce the size of the graph.</p>
    <br/>
    <form action="#" method="post">
        {{ form.selection(class="form-control", style="width: 200px; height: 200px;") }}
        <br/>
        {{ form.submit(class="btn btn-default") }}
        <br/>
    </form>
    <div class="col-md-12 col-sm-12">
        {{ graph|safe }}
    </div>
{% endblock %}